@@ -3,7 +3,7 @@
 macro_rules! cfg_server {
     ($($item:item)*) => {
         $(
-            #[cfg(all(feature = "server"))]
+            #[cfg(feature = "server")]
             $item
         )*
     }
@@ -12,7 +12,7 @@ macro_rules! cfg_server {
 macro_rules! cfg_macros {
     ($($item:item)*) => {
         $(
-            #[cfg(all(feature = "macros"))]
+            #[cfg(feature = "macros")]
             $item
         )*
     }
@@ -21,7 +21,7 @@ macro_rules! cfg_macros {
 macro_rules! cfg_game {
     ($($item:item)*) => {
         $(
-            #[cfg(all(feature = "game"))]
+            #[cfg(feature = "game")]
             $item
         )*
     }
@@ -30,7 +30,7 @@ macro_rules! cfg_game {
 macro_rules! cfg_flat_buffers_helpers {
     ($($item:item)*) => {
         $(
-            #[cfg(all(feature = "flat_buffers_helpers"))]
+            #[cfg(feature = "flat_buffers_helpers")]
             $item
         )*
     }
