@@ -1,5 +1,7 @@
 use async_trait::async_trait;
 use bytes::Bytes;
+#[cfg(feature = "flat_buffers_helpers")]
+use flatbuffers::FlatBufferBuilder;
 use std::{
     fmt::Debug,
     net::SocketAddr,
@@ -77,6 +79,22 @@ impl SocketTools {
         self.latency.load(Ordering::Acquire)
     }
 
+    #[cfg(feature = "flat_buffers_helpers")]
+    pub fn send_flat_buffers<
+        F: 'static + Fn(&mut FlatBufferBuilder<'static>) -> Result<Bytes, Error> + Send + Sync,
+    >(
+        &self,
+        f: F,
+    ) {
+        if self
+            .tx
+            .send(WriterMessage::SendFlatBuffers(Box::new(f)))
+            .is_err()
+        {
+            log::error!("Can't send the data to the channel.");
+        }
+    }
+
     /// Close the session
     pub fn close(&self) -> Result<(), Error> {
         self.tx
