@@ -7,6 +7,8 @@ use super::world::World;
 use super::world_session::WorldSession;
 use super::world_socket_mgr::ACTIVE_SOCKETS;
 use bytes::Bytes;
+#[cfg(feature = "flat_buffers_helpers")]
+use flatbuffers::FlatBufferBuilder;
 use std::convert::TryInto;
 use std::marker::PhantomData;
 use std::sync::atomic::Ordering;
@@ -14,7 +16,7 @@ use std::sync::Arc;
 use std::time::Duration;
 use tokio::io::AsyncWriteExt;
 use tokio::sync::mpsc::{unbounded_channel, UnboundedSender};
-use tokio::task::JoinHandle;
+use tokio::task::{yield_now, JoinHandle};
 use tokio::time::{sleep, timeout};
 use tokio::{
     io::{AsyncRead, AsyncWrite, BufReader, ReadHalf, WriteHalf},
@@ -164,7 +166,7 @@ where
         let size = reader.read_size().await?;
         let cmd = reader.read_cmd().await?;
 
-        let (limit, size_limit, policy) = self.world.get_packet_limits(cmd);
+        let (limit, size_limit, policy) = self.world.get_packet_limit(cmd);
 
         if (size as u32) >= size_limit || size >= MAX_SIZE {
             return Err(Error::PacketSize);
@@ -199,6 +201,8 @@ where
     }
 
     async fn write(mut writer: WriteHalf<S>, mut rx: UnboundedReceiver<WriterMessage>) {
+        #[cfg(feature = "flat_buffers_helpers")]
+        let mut builder = flatbuffers::FlatBufferBuilder::new();
         while let Some(message) = rx.recv().await {
             match message {
                 WriterMessage::Close => break,
@@ -208,23 +212,33 @@ where
                 }
                 WriterMessage::Bytes(data) => {
                     if data.is_empty() {
+                        yield_now().await;
                         continue;
                     }
 
                     if writer.write_all(&data).await.is_err() {
                         break;
                     }
-
-                    task::yield_now().await;
+                }
+                #[cfg(feature = "flat_buffers_helpers")]
+                WriterMessage::SendFlatBuffers(f) => {
+                    if let Ok(bytes) = f(&mut builder) {
+                        if writer.write_all(&bytes).await.is_err() {
+                            break;
+                        }
+                    }
+                    builder.reset();
                 }
             }
+
+            yield_now().await;
         }
     }
 }
 
 fn parse_ping(content: Vec<u8>) -> Result<i64, Error> {
     if content.len() == 16 {
-        let middle = content.len() - 8;
+        let middle = content.len() / 2;
         let latency = content[middle..]
             .try_into()
             .map_err(|_| Error::PacketPayload)?;
@@ -239,6 +253,10 @@ pub(crate) enum WriterMessage {
     Close,
     CloseDelayed(Duration),
     Bytes(Bytes),
+    #[cfg(feature = "flat_buffers_helpers")]
+    SendFlatBuffers(
+        Box<dyn Fn(&mut FlatBufferBuilder<'static>) -> Result<Bytes, Error> + Send + Sync>,
+    ),
 }
 
 pub(crate) enum PacketDispatcher {
