@@ -128,7 +128,7 @@ where
     }
 
     fn set_up_socket(socket: &mut TcpStream) -> Result<(), Error> {
-        socket.set_nodelay(true).map_err(|_| Error::DosProtection)
+        socket.set_nodelay(true).map_err(|_| Error::NoDelayError)
     }
 
     const TIMEOUT_TLS: u64 = 15;
@@ -146,8 +146,8 @@ where
                 acceptor.accept(socket),
             )
             .await
-            .map_err(|_| Error::DosProtection)?
-            .map_err(|_| Error::TlsAcceptTimeout)?;
+            .map_err(|_| Error::TlsAcceptTimeout)?
+            .map_err(|_| Error::TlsAccept)?;
             Ok(Self::split_socket(socket.into_inner().0))
         } else {
             Ok(Self::split_socket(socket))
